@@ -70,19 +70,25 @@ class FSSpecClient(Client):
         return client, path
 
     async def fetch(self, listing):
-        root_id = await listing.insert_root()
+        data_storage = listing.data_storage.clone()
+        root_id = await listing.insert_root(data_storage=data_storage)
         progress_bar = tqdm(desc=f"Listing {self.uri}", unit=" objects")
         loop = get_loop()
 
         queue = asyncio.Queue()
         queue.put_nowait((root_id, ""))
 
-        async def worker(queue):
+        async def worker(queue, data_storage):
             while True:
                 dir_id, prefix = await queue.get()
                 try:
                     subdirs = await self._fetch_dir(
-                        dir_id, prefix, "/", progress_bar, listing
+                        dir_id,
+                        prefix,
+                        "/",
+                        progress_bar,
+                        listing,
+                        data_storage,
                     )
                     for subdir in subdirs:
                         queue.put_nowait(subdir)
@@ -91,14 +97,16 @@ class FSSpecClient(Client):
 
         workers = []
         for _ in range(FETCH_WORKERS):
-            workers.append(loop.create_task(worker(queue)))
+            workers.append(loop.create_task(worker(queue, data_storage)))
 
         await queue.join()
         for worker in workers:
             worker.cancel()
         await asyncio.gather(*workers)
 
-    async def _fetch_dir(self, dir_id, prefix, delimiter, pbar, listing):
+    async def _fetch_dir(
+        self, dir_id, prefix, delimiter, pbar, listing, data_storage
+    ):
         path = f"{self.name}/{prefix}"
         # pylint:disable-next=protected-access
         infos = await self.fs._ls(path, detail=True, versions=True)
@@ -110,21 +118,25 @@ class FSSpecClient(Client):
             if info["type"] == "directory":
                 name = full_path.split(delimiter)[-1]
                 new_dir_id = await listing.insert_dir(
-                    dir_id, name, datetime.max, subprefix
+                    dir_id,
+                    name,
+                    datetime.max,
+                    subprefix,
+                    data_storage=data_storage,
                 )
                 subdirs.add((new_dir_id, subprefix))
             else:
                 files.append(
-                    self._df_from_info(info, dir_id, delimiter, subprefix)
+                    self._dict_from_info(info, dir_id, delimiter, subprefix)
                 )
         if files:
-            await listing.data_storage.insert(files, is_dir=False)
+            await data_storage.insert_entries(files)
         pbar.update(len(subdirs) + len(files))
         return subdirs
 
     @classmethod
     @abstractmethod
-    def _df_from_info(cls, v, dir_id, delimiter, path):
+    def _dict_from_info(cls, v, parent_id, delimiter, path):
         ...
 
     def fetch_nodes(
