@@ -118,7 +118,7 @@ class SQLiteDataStorage(AbstractDataStorage):
             """
             CREATE TABLE IF NOT EXISTS buckets
             (
-                uri        TEXT PRIMARY KEY NOT NULL,
+                uri         TEXT PRIMARY KEY NOT NULL,
                 timestamp   DATETIME,
                 expires     DATETIME,
                 status      INTEGER NOT NULL
@@ -459,17 +459,18 @@ class SQLiteDataStorage(AbstractDataStorage):
         return Storage(*res[0])
 
     @retry_sqlite_locks
-    def upsert_storage(self, uri: str) -> Storage:
-        storage = Storage(uri)
+    def create_storage_if_not_registered(
+        self, uri: str, commit: bool = True
+    ) -> None:
         self.db.execute(
             """
             INSERT INTO buckets(uri, status) VALUES (?, ?)
             ON CONFLICT(uri) DO NOTHING
             """,
-            [uri, storage.status],
+            [uri, StorageStatus.CREATED],
         )
-        self.db.commit()
-        return storage
+        if commit:
+            self.db.commit()
 
     def register_storage_for_indexing(
         self, uri: str, force_update: bool = True
@@ -482,27 +483,37 @@ class SQLiteDataStorage(AbstractDataStorage):
             - boolean saying if indexing is needed
             - boolean saying if indexing is currently pending (running)
         """
-        # create storage if doesn't exist
-        storage = self.upsert_storage(uri)
+        # This ensures that all calls to the DB are in a single transaction
+        # and commit is automatically called once this function returns
+        with self.db:
+            # Create storage if it doesn't exist
+            self.create_storage_if_not_registered(uri, commit=False)
+            saved_storage = self.get_storage(uri)
 
-        # TODO open transaction, get storage and lock it
+            assert (
+                saved_storage is not None
+            ), f"Unexpected error, storage for {uri} doesn't exist"
+            storage: Storage = saved_storage
 
-        if storage.status == StorageStatus.PENDING:
-            return storage, False, True
+            if storage.status == StorageStatus.PENDING:
+                return storage, False, True
 
-        elif storage.is_expired:
-            storage = self.mark_storage_pending(storage)
-            return storage, True, False
+            elif storage.is_expired:
+                storage = self.mark_storage_pending(storage, commit=False)
+                return storage, True, False
 
-        elif storage.status == StorageStatus.COMPLETE and not force_update:
-            return storage, False, False
+            elif storage.status == StorageStatus.COMPLETE and not force_update:
+                return storage, False, False
 
-        else:
-            storage = self.mark_storage_pending(storage)
-            return storage, True, False
+            else:
+                storage = self.mark_storage_pending(storage, commit=False)
+                return storage, True, False
 
-    def mark_storage_pending(self, storage: Storage) -> Storage:
-        # update status to pending and dates
+    @retry_sqlite_locks
+    def mark_storage_pending(
+        self, storage: Storage, commit: bool = True
+    ) -> Storage:
+        # Update status to pending and dates
         storage = storage._replace(
             status=StorageStatus.PENDING, timestamp=None, expires=None
         )
@@ -520,6 +531,8 @@ class SQLiteDataStorage(AbstractDataStorage):
                 storage.uri,
             ],
         )
+        if commit:
+            self.db.commit()
 
         return storage
 
@@ -588,6 +601,10 @@ class SQLiteDataStorage(AbstractDataStorage):
         return map(Node._make, result)
 
     def size(self, node: NodeWithPath) -> Tuple[int, int]:
+        if not node.is_dir:
+            # Return node size if this is not a directory
+            return node.size, 1
+
         parent_path_str = node.path_str
 
         results = self.db.execute(
@@ -656,14 +673,19 @@ class SQLiteDataStorage(AbstractDataStorage):
         node: NodeWithPath,
         names=None,
         inames=None,
+        paths=None,
+        ipaths=None,
+        size=None,
         type=None,  # pylint: disable=redefined-builtin
         jmespath="",
     ) -> Iterable[NodeWithPath]:
         if jmespath:
             raise NotImplementedError("jmespath queries not supported!")
-        name_filter = utils.sql_file_filter(names, inames, type)
+        custom_filter = utils.sql_file_filter(
+            names, inames, paths, ipaths, size, type
+        )
         try:
-            return self.walk_subtree(node, custom_filter=name_filter)
+            return self.walk_subtree(node, custom_filter=custom_filter)
         except FileNotFoundError:
             return []
 
