@@ -35,6 +35,109 @@ def test_find(cloud_test_catalog):
         )
 
 
+@pytest.mark.parametrize("cloud_test_catalog", ["s3", "gcs"], indirect=True)
+def test_find_names_paths_size_type(cloud_test_catalog):
+    src = cloud_test_catalog.src
+    catalog = cloud_test_catalog.catalog
+    config = cloud_test_catalog.client_config
+
+    assert set(
+        catalog.find([str(src)], names=["*cat*"], client_config=config)
+    ) == {
+        str(src / "cats") + "/",
+        str(src / "cats" / "cat1"),
+        str(src / "cats" / "cat2"),
+    }
+
+    assert set(
+        catalog.find(
+            [str(src)], names=["*cat*"], typ="dir", client_config=config
+        )
+    ) == {
+        str(src / "cats") + "/",
+    }
+
+    assert (
+        len(
+            list(
+                catalog.find([str(src)], names=["*CAT*"], client_config=config)
+            )
+        )
+        == 0
+    )
+
+    assert set(
+        catalog.find([str(src)], inames=["*CAT*"], client_config=config)
+    ) == {
+        str(src / "cats") + "/",
+        str(src / "cats" / "cat1"),
+        str(src / "cats" / "cat2"),
+    }
+
+    assert set(
+        catalog.find([str(src)], paths=["*cats/cat*"], client_config=config)
+    ) == {
+        str(src / "cats" / "cat1"),
+        str(src / "cats" / "cat2"),
+    }
+
+    assert (
+        len(
+            list(
+                catalog.find(
+                    [str(src)], paths=["*caTS/CaT**"], client_config=config
+                )
+            )
+        )
+        == 0
+    )
+
+    assert set(
+        catalog.find([str(src)], ipaths=["*caTS/CaT*"], client_config=config)
+    ) == {
+        str(src / "cats" / "cat1"),
+        str(src / "cats" / "cat2"),
+    }
+
+    assert set(
+        catalog.find([str(src)], size="5", typ="f", client_config=config)
+    ) == {
+        str(src / "description"),
+    }
+
+    assert set(
+        catalog.find([str(src)], size="-3", typ="f", client_config=config)
+    ) == {
+        str(src / "dogs" / "dog2"),
+    }
+
+
+@pytest.mark.parametrize("cloud_test_catalog", ["s3", "gcs"], indirect=True)
+def test_find_names_columns(cloud_test_catalog):
+    src = cloud_test_catalog.src
+    catalog = cloud_test_catalog.catalog
+    config = cloud_test_catalog.client_config
+
+    src_str = str(src)
+    owner = "webfile" if src_str.startswith("s3") else ""
+
+    assert set(
+        catalog.find(
+            [src_str],
+            names=["*cat*"],
+            columns=["du", "name", "owner", "path", "size", "type"],
+            client_config=config,
+        )
+    ) == {
+        "\t".join(columns)
+        for columns in [
+            ["8", "cats", "", str(src / "cats") + "/", "0", "d"],
+            ["4", "cat1", owner, str(src / "cats" / "cat1"), "4", "f"],
+            ["4", "cat2", owner, str(src / "cats" / "cat2"), "4", "f"],
+        ]
+    }
+
+
 @pytest.mark.parametrize("cloud_test_catalog", ["s3", "gcs"], indirect=True)
 @pytest.mark.parametrize(
     "recursive,star",
