@@ -6,6 +6,7 @@ import pytest
 from dql.cli import (
     TTL_HUMAN,
     TTL_INT,
+    find_columns_type,
     get_logging_level,
     get_parser,
     human_time_type,
@@ -24,6 +25,16 @@ def test_human_time_type():
         human_time_type("bogus")
 
 
+def test_find_columns_type():
+    assert find_columns_type("") == ["path"]
+    assert find_columns_type("du") == ["du"]
+    assert find_columns_type("", default_colums_str="name") == ["name"]
+    assert find_columns_type("du, name,PATH") == ["du", "name", "path"]
+
+    with pytest.raises(ArgumentTypeError):
+        find_columns_type("bogus")
+
+
 def test_cli_parser():
     parser = get_parser()
 
